.. image:: https://travis-ci.org/coddingtonbear/django-mailbox.png?branch=master
   :target: https://travis-ci.org/coddingtonbear/django-mailbox

Easily pull messages from POP3, IMAP, or local mailboxes into Django models.

This Django application will allow you to specify mailboxes that you would like consumed for incoming content; 
the e-mail will be stored in the database, and you can process it at will (or, if you're in a hurry, by subscribing to a signal).

- Documentation for django-mailbox is available on
  `ReadTheDocs <http://django-mailbox.readthedocs.org/>`_.
- Please post issues on
  `Github <http://github.com/coddingtonbear/django-mailbox/issues>`_.
- Test status available on
  `Travis-CI <https://travis-ci.org/coddingtonbear/django-mailbox>`_.



.. image:: https://d2weczhvl823v0.cloudfront.net/coddingtonbear/django-mailbox/trend.png
   :alt: Bitdeli badge
   :target: https://bitdeli.com/free

